@@ -21,19 +21,6 @@ from petrus._core.calcs.Text import Text
 
 
 class Prog(BaseCalc):
-    INPUTS = {
-        "author": "The author of the project.",
-        "classifiers": "The classifiers of the project. Comma separated. You may include {mit} or {preset}. Recommended value is '{preset}, {mit}, Programming Language :: Python, Programming Language :: Python :: 3, Programming Language :: Python :: 3 :: Only'.",
-        "description": "The description of the project.",
-        "development_status": "The projects development status. Communicated as a classifier. May be 'infer'.",
-        "email": "Email of the author.",
-        "requires_python": "The python version of the project. A list separated by '\\|'. The first non empty item is used. You may use {preset} and {current}. Recommended value is '{preset} \\| {current}'.",
-        "github": "The github username for linking the source.",
-        "token": "The PyPI token.",
-        "v": "Version string for the project. Recommended is 'bump(2, 1)'.",
-        "vformat": "Format of the version string, i.e. how many numerals in the release string. Recommended is '3'.",
-        "year": "Year of creating the project. Recommended is '{current}'.",
-    }
 
     def __init__(self: Self, kwargs: Any, /) -> None:
         self.kwargs = kwargs
